@@ -6,7 +6,7 @@
 namespace Config
 {
     extern QString dir_data;
-    extern double swr_bw_max, Z_Target;
+    extern double swr_max, swr_bw_max, Z_Target;
     extern const char
       *Org,*App,*DOM_ENCODING;
 
