@@ -18,7 +18,7 @@ public:
 
     Graph graph;
     GraphScale *xscale,*yscale1, *yscale2;
-    GraphTrace *swrtrace, *ztrace, *xtrace, *x2trace, *rtrace;
+    GraphTrace *swrtrace, *ztrace, *xtrace, *rtrace;
     GraphVertLine *swrminline;
     GraphHorizLine *ZTargetline,*SWRTargetline;
 
