@@ -13,7 +13,7 @@
 #include "ui_mainwindow.h"
 
 const Version
-    MainWindow::version = Version(0,9,7,"");
+    MainWindow::version = Version(0,9,8,"");
 
 ScanData scandata;
 
@@ -52,7 +52,7 @@ setlinebuf(stdout);
     connect(ui->fspan, SIGNAL(valueChanged(double)), this, SLOT(Slot_fspan_change(double)));
     connect(ui->point_count, SIGNAL(valueChanged(int)), this, SLOT(Slot_point_count_change(int)));
 
-    QCheckBox *ctrls[] = {ui->plotz_chk,ui->plotx_chk,ui->plotx2_chk,ui->plotr_chk,NULL};
+    QCheckBox *ctrls[] = {ui->plotz_chk,ui->plotx_chk,ui->plotr_chk,NULL};
     for (int i=0; ctrls[i]; i++)
         connect(ctrls[i], SIGNAL(stateChanged(int)), this, SLOT(Slot_plot_change(int)));
 
@@ -65,6 +65,9 @@ setlinebuf(stdout);
     Slot_scanDummyBtn_click();
 
     ui->canvas1->cursor = ui->cursor;
+
+    ui->tabWidget->setCurrentIndex(1);
+    ui->tabWidget->setTabEnabled(0,false);
 }
 
 
@@ -96,7 +99,7 @@ void MainWindow::populate_table()
         ui->scan_data->setItem(i, 2, new QTableWidgetItem(QString("%1").arg(point->Z)));
         ui->scan_data->setItem(i, 3, new QTableWidgetItem(QString("%1").arg(point->R)));
         ui->scan_data->setItem(i, 4, new QTableWidgetItem(QString("%1").arg(point->X)));
-        ui->scan_data->setItem(i, 5, new QTableWidgetItem(QString("%1").arg(point->X2)));
+        //ui->scan_data->setItem(i, 5, new QTableWidgetItem(QString("%1").arg(point->X2)));
     }
 }
 
@@ -112,16 +115,17 @@ void MainWindow::draw_graph1()
 
     scale = ui->canvas1->yscale1;
     scale->vmin = 1.0;
-    scale->vmax = scandata.points[scandata.swr_max_idx].swr;
+    scale->vmax = scandata.points[scandata.swr_max_idx].swr>Config::swr_max ? Config::swr_max : scandata.points[scandata.swr_max_idx].swr;
     scale->SetIncAuto();
 
     scale = ui->canvas1->yscale2;
     scale->vmin = 0.0; //scandata.points[scandata.Z_min_idx].Z;
     scale->vmax = 0.0;
     if (ui->canvas1->ztrace->enabled && scandata.points[scandata.Z_max_idx].Z>scale->vmax) scale->vmax=scandata.points[scandata.Z_max_idx].Z;
-    if (ui->canvas1->xtrace->enabled && scandata.points[scandata.X_max_idx].X>scale->vmax) scale->vmax=scandata.points[scandata.X_max_idx].X;
+    //if (ui->canvas1->xtrace->enabled && scandata.points[scandata.X_max_idx].X>scale->vmax) scale->vmax=scandata.points[scandata.X_max_idx].X;
+    if (ui->canvas1->xtrace->enabled) scale->Expand(scandata.points[scandata.X_min_idx].X,scandata.points[scandata.X_max_idx].X);
     if (ui->canvas1->rtrace->enabled && scandata.points[scandata.R_max_idx].R>scale->vmax) scale->vmax=scandata.points[scandata.R_max_idx].R;
-    if (ui->canvas1->x2trace->enabled && scandata.points[scandata.X2_min_idx].X2<scale->vmin) scale->vmin=scandata.points[scandata.X2_min_idx].X2;
+    //if (ui->canvas1->x2trace->enabled && scandata.points[scandata.X2_min_idx].X2<scale->vmin) scale->vmin=scandata.points[scandata.X2_min_idx].X2;
     if (scale->vmax==0.0) scale->vmax=1.0;
     scale->SetIncAuto();
     scale->SetMinAuto();
@@ -138,9 +142,9 @@ void MainWindow::draw_graph1()
     for (unsigned int i=0;i<scandata.points.size();i++)
         ui->canvas1->xtrace->points[i] = scandata.points[i].X;
 
-    ui->canvas1->x2trace->points.resize(scandata.points.size());
-    for (unsigned int i=0;i<scandata.points.size();i++)
-        ui->canvas1->x2trace->points[i] = scandata.points[i].X2;
+//    ui->canvas1->x2trace->points.resize(scandata.points.size());
+//    for (unsigned int i=0;i<scandata.points.size();i++)
+//        ui->canvas1->x2trace->points[i] = scandata.points[i].X2;
 
     ui->canvas1->rtrace->points.resize(scandata.points.size());
     for (unsigned int i=0;i<scandata.points.size();i++)
@@ -171,9 +175,14 @@ void MainWindow::Slot_scanBtn_click()
     scandata.SetPointCount(ui->point_count->value());
 
     if (link->IsUp())
+    {
         link->Cmd_Scan((long)(scandata.freq_start),
-                      (long)(scandata.freq_end),
-                      (long)((scandata.freq_end-scandata.freq_start)/scandata.GetPointCount()), this);
+                  (long)(scandata.freq_end),
+                  (long)((scandata.freq_end-scandata.freq_start)/scandata.GetPointCount()),
+                  ui->useraw_chk->checkState()==Qt::Checked,
+                  this);
+        link->Cmd_Off(this);
+    }
 
     populate_table();
     draw_graph1();
@@ -283,7 +292,7 @@ void MainWindow::Slot_plot_change(int)
 {
     ui->canvas1->ztrace->enabled = ui->plotz_chk->checkState()==Qt::Checked;
     ui->canvas1->xtrace->enabled = ui->plotx_chk->checkState()==Qt::Checked;
-    ui->canvas1->x2trace->enabled = ui->plotx2_chk->checkState()==Qt::Checked;
+    //ui->canvas1->x2trace->enabled = ui->plotx2_chk->checkState()==Qt::Checked;
     ui->canvas1->rtrace->enabled = ui->plotr_chk->checkState()==Qt::Checked;
     draw_graph1();
 //    ui->canvas1->update();
@@ -443,16 +452,15 @@ void MainWindow::Slot_Settings()
 
 void MainWindow::Slot_copy()
 {
-  QString txt("freq\tSWR\tZ\tR\tX\tX2\n");
+  QString txt("freq\tSWR\tZ\tR\tX\n");
 
   for (unsigned int i=0;i<scandata.points.size();i++)
-     txt += QString("%1\t%2\t%3\t%4\t%5\n")
+     txt += QString("%1\t%2\t%3\t%4\n")
              .arg(scandata.points[i].freq/1000000.0,0,'f')
              .arg(scandata.points[i].swr)
              .arg(scandata.points[i].Z)
              .arg(scandata.points[i].R)
-             .arg(scandata.points[i].X)
-             .arg(scandata.points[i].X2);
+             .arg(scandata.points[i].X);
 
   qApp->clipboard()->setText(txt);
 }
