@@ -19,7 +19,8 @@ public:
     int RxFlush();
 
     bool IsUp();
-    void Cmd_Scan(long fstart, long fend, long fstep, EventReceiver *erx);
+    void Cmd_Scan(long fstart, long fend, long fstep, bool useraw, EventReceiver *erx);
+    void Cmd_Off(EventReceiver *erx);
 
     QString devname;
 
